local GUI = {}
_G["ClassicRaidAssistGUI"] = GUI
local AceGUI = LibStub("AceGUI-3.0")

LibStub("AceHook-3.0"):Embed(GUI)

local version = GetAddOnMetadata("ClassicRaidAssist", "Version")

local AceGUI = LibStub("AceGUI-3.0")
local frame = nil

function GUI:Toggle()
    if(frame:IsShown()) then
        frame:Hide()
    else
        frame:Show()
    end
end

function GUI:DrawSettings(container)
    local settingsContainer = AceGUI:Create("InlineGroup")
    settingsContainer:SetTitle("Settings:")
    settingsContainer:SetFullWidth(true)
    settingsContainer:SetLayout("Flow")

    container:AddChild(settingsContainer)

    local itemScanningCheckBox = AceGUI:Create("CheckBox")
    -- itemScanningCheckBox:SetWidth(90)
    itemScanningCheckBox:SetValue(ClassicRaidAssist.db.char.allowItemScanning)
    itemScanningCheckBox:SetLabel("Allow Item Scanning")
    itemScanningCheckBox:SetCallback("OnValueChanged", function() ClassicRaidAssist.db.char.allowItemScanning = not ClassicRaidAssist.db.char.allowItemScanning end)

    settingsContainer:AddChild(itemScanningCheckBox)



    local scanBtn = AceGUI:Create("Button")
    scanBtn:SetText("Scan for versions")
    scanBtn:SetWidth(400)
    if not (IsInGroup() or IsInRaid()) then
        scanBtn:SetDisabled(true)
        scanBtn:SetText("Can't scan, not in a group")
    end
    scanBtn:SetCallback("OnClick", function()
        ClassicRaidAssist:Scan()
        ClassicRaidAssist.db.char.settingsContainer = container
        container:ReleaseChildren()
        GUI:DrawSettings(container)
    end)
    container:AddChild(scanBtn)


    
    local raidContainer = AceGUI:Create("SimpleGroup")
    local leftContainer = AceGUI:Create("SimpleGroup")
    local rightContainer = AceGUI:Create("SimpleGroup")
    raidContainer:SetWidth(400)
    raidContainer:SetLayout("Flow")
    leftContainer:SetWidth(200)
    leftContainer:SetLayout("Flow")
    rightContainer:SetWidth(200)
    rightContainer:SetLayout("Flow")
    currentCount = 0
    for i = 1, MAX_RAID_MEMBERS do
        local tempPlayerName, _, _, _, class, englishClass = GetRaidRosterInfo(i)
        if(tempPlayerName ~= nil and class ~= nil) then
            currentCount = currentCount + 1
            local currPlayerName, currPlayerRealm = UnitName(tempPlayerName)
            local playerContainer = AceGUI:Create("SimpleGroup")
            playerContainer:SetLayout("Flow")
            playerContainer:SetWidth(200)

            local curr_name = AceGUI:Create("Label")
            curr_name:SetWidth(100)
            curr_name:SetText("|c" .. RAID_CLASS_COLORS[englishClass].colorStr .. currPlayerName .. "|r")

            local status = AceGUI:Create("Label")
            status:SetWidth(100)
            
            if(ClassicRaidAssist.raid[currPlayerName] == nil) then
                status:SetText("|cffff0000MISSING|r")
            elseif(ClassicRaidAssist.raid[currPlayerName] ~= version) then
                status:SetText("|cffffff00" .. ClassicRaidAssist.raid[currPlayerName] .. "|r")
            elseif(ClassicRaidAssist.raid[currPlayerName] == version) then
                status:SetText("|cff00b300" .. ClassicRaidAssist.raid[currPlayerName] .. "|r")
            end
            playerContainer:AddChild(curr_name)
            playerContainer:AddChild(status)
            if(i <= 20) then
                leftContainer:AddChild(playerContainer)
            else
                rightContainer:AddChild(playerContainer)
            end
        end
    end
    
    -- Keep spacing in scan raid tab, fill in with blanks
    if(currentCount <= 20) then
        for i = currentCount, 20 do
            local playerContainer = AceGUI:Create("SimpleGroup")
            playerContainer:SetLayout("Flow")
            playerContainer:SetWidth(200)

            local curr_name = AceGUI:Create("Label")
            curr_name:SetWidth(100)
            curr_name:SetText(" ")
            playerContainer:AddChild(curr_name)
            leftContainer:AddChild(playerContainer)
        end
    else
        for i = currentCount, 39 do
            local playerContainer = AceGUI:Create("SimpleGroup")
            playerContainer:SetLayout("Flow")
            playerContainer:SetWidth(200)

            local curr_name = AceGUI:Create("Label")
            curr_name:SetWidth(100)
            curr_name:SetText(" ")
            playerContainer:AddChild(curr_name)
            rightContainer:AddChild(playerContainer)
        end
    end

    raidContainer:AddChild(leftContainer)
    raidContainer:AddChild(rightContainer)
    container:AddChild(raidContainer)
end

local function SelectGroup(container, event, group)
    container:ReleaseChildren()
    ClassicRaidAssist.db.char.currentTab = group
    if group == "settings" then
        GUI:DrawSettings(container)
    elseif group == "raidBuffs" then
        RaidBuffsTab:DrawRaidBuffs(container)
    elseif group == "worldBuffs" then
        WorldBuffsTab:DrawWorldBuffs(container)
    elseif group == "raidItems" then
        RaidItemsTab:DrawRaidItems(container)
    end
end

function GUI:SetUpGUI()
    frame = AceGUI:Create("Frame")
    _G["ClassicRaidAssistGUI_frame"] = frame
    -- frame:Hide()
    frame:EnableResize(false)
    frame:SetWidth(460)
    frame:SetTitle("Classic Raid Assist")
    frame:SetStatusText("Addon By Zanzabarr")
    tinsert(UISpecialFrames, "ClassicRaidAssistGUI_frame")
    frame:SetLayout("Fill")
    local tabGroup = AceGUI:Create("TabGroup")
    tabGroup:SetTabs({
        {value = "raidBuffs", text = "Raid Buffs" },
        {value = "worldBuffs", text = "World Buffs" },
        {value = "raidItems", text = "Raid Items" },
        {value = "settings", text = "Settings" },
    })
    tabGroup:SetCallback("OnGroupSelected", SelectGroup)
    tabGroup:SelectTab("raidBuffs")
    frame:AddChild(tabGroup)
end